"""
LNKD - A simple utility adding custom tags to YAML.
"""

from functools import partial

from .base import CustomTag
from .tag import LinkedTag
from .loader import LinkedLoader
from .dumper import LinkedDumper


__all__ = [
    "LinkedTag",
    "CustomTag",
    "LinkedLoader",
    "LinkedDumper"
]



from setuptools import Extension, setup, find_packages

setup(
    name="lnkd",
    version="0.1.0",
    description="Apogee",
    author="Mark Douthwaite",
    author_email="mark.douthwaite@peak.ai",
    packages=find_packages(exclude=["contrib", "docs", "tests*"]),
    install_requires=["requests", "pyyaml"],
    include_package_data=True,
)


from typing import Optional, List, Any

from yaml import SafeDumper

from .tag import LinkedTag
from .utils import _CustomScalarNode


class LinkedDumper(SafeDumper):

    yaml_multi_representers = {
        **SafeDumper.yaml_multi_representers.copy(),
        LinkedTag: LinkedTag.to_yaml,
        _CustomScalarNode: _CustomScalarNode.to_yaml,
    }

